@@ -75,12 +75,14 @@ from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import servicetype
 from neutron_lib.api.definitions import sfc
 from neutron_lib.api.definitions import sorting
+from neutron_lib.api.definitions import standard_attr_segment
 from neutron_lib.api.definitions import subnet
 from neutron_lib.api.definitions import subnet_onboard
 from neutron_lib.api.definitions import subnet_segmentid_writable
 from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import trunk
 from neutron_lib.api.definitions import trunk_details
+from neutron_lib.api.definitions import uplink_status_propagation
 from neutron_lib.api.definitions import vlantransparent
 from neutron_lib.api.definitions import vpn
 from neutron_lib.api.definitions import vpn_endpoint_groups
@@ -153,12 +155,14 @@ _ALL_API_DEFINITIONS = {
     servicetype,
     sfc,
     sorting,
+    standard_attr_segment,
     subnet,
     subnet_onboard,
     subnet_segmentid_writable,
     subnetpool,
     trunk,
     trunk_details,
+    uplink_status_propagation,
     vlantransparent,
     vpn,
     vpn_endpoint_groups,
