@@ -86,12 +86,14 @@ KNOWN_EXTENSIONS = (
     'dns-domain-ports',
     'dns-integration',
     'dvr',
+    'empty-string-filtering',
     'ext-gw-mode',
     'external-net',
     'extra_dhcp_opt',
     'extraroute',
     'fip-port-details',
     'flavors',
+    'floating-ip-port-forwarding',
     'ip-substring-filtering',
     'l3-ha',
     'l3_agent_scheduler',
@@ -138,6 +140,10 @@ KNOWN_EXTENSIONS = (
     'vpnaas',
     'vpn-endpoint-groups',
     'vpn-flavors',
+
+    # http://git.openstack.org/cgit/openstack/networking-sfc:
+    'flow_classifier',
+    'sfc',
 )
 
 KNOWN_KEYWORDS = (
