@@ -64,20 +64,29 @@ RESOURCE_ATTRIBUTE_MAP = {
         'id': {'allow_post': False, 'allow_put': False,
                'validate': {'type:uuid': None},
                'is_visible': True,
+               'is_filter': True,
+               'is_sort_key': True,
                'primary_key': True},
         'name': {'allow_post': True, 'allow_put': True,
                  'validate': {'type:string': constants.NAME_FIELD_SIZE},
+                 'is_filter': True,
+                 'is_sort_key': True,
                  'is_visible': True, 'default': ''},
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
                            'convert_to': converters.convert_to_boolean,
+                           'is_filter': True,
+                           'is_sort_key': True,
                            'is_visible': True},
         'status': {'allow_post': False, 'allow_put': False,
+                   'is_sort_key': True,
                    'is_visible': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
                       'required_by_policy': True,
                       'validate': {
                           'type:string': constants.PROJECT_ID_FIELD_SIZE},
+                      'is_filter': True,
+                      'is_sort_key': True,
                       'is_visible': True},
         EXTERNAL_GW_INFO: {'allow_post': True, 'allow_put': True,
                            'is_visible': True, 'default': None,
@@ -100,9 +109,12 @@ RESOURCE_ATTRIBUTE_MAP = {
         'id': {'allow_post': False, 'allow_put': False,
                'validate': {'type:uuid': None},
                'is_visible': True,
+               'is_filter': True,
+               'is_sort_key': True,
                'primary_key': True},
         'floating_ip_address': {'allow_post': True, 'allow_put': False,
                                 'validate': {'type:ip_address_or_none': None},
+                                'is_sort_key': True,
                                 'is_visible': True, 'default': None,
                                 'enforce_policy': True},
         'subnet_id': {'allow_post': True, 'allow_put': False,
@@ -111,23 +123,29 @@ RESOURCE_ATTRIBUTE_MAP = {
                       'default': None},
         'floating_network_id': {'allow_post': True, 'allow_put': False,
                                 'validate': {'type:uuid': None},
+                                'is_filter': True, 'is_sort_key': True,
                                 'is_visible': True},
         'router_id': {'allow_post': False, 'allow_put': False,
                       'validate': {'type:uuid_or_none': None},
+                      'is_filter': True, 'is_sort_key': True,
                       'is_visible': True, 'default': None},
         'port_id': {'allow_post': True, 'allow_put': True,
                     'validate': {'type:uuid_or_none': None},
+                    'is_filter': True,
                     'is_visible': True, 'default': None,
                     'required_by_policy': True},
         'fixed_ip_address': {'allow_post': True, 'allow_put': True,
                              'validate': {'type:ip_address_or_none': None},
+                             'is_filter': True, 'is_sort_key': True,
                              'is_visible': True, 'default': None},
         'tenant_id': {'allow_post': True, 'allow_put': False,
                       'required_by_policy': True,
                       'validate': {
                           'type:string': constants.PROJECT_ID_FIELD_SIZE},
+                      'is_filter': True, 'is_sort_key': True,
                       'is_visible': True},
         'status': {'allow_post': False, 'allow_put': False,
+                   'is_filter': True, 'is_sort_key': True,
                    'is_visible': True},
     },
 }
